/*
 * 
 * Copyright 2002-2004 The Ant-Contrib project
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package net.sf.antcontrib.cpptasks.parser;
import java.io.IOException;
import java.io.Reader;
import java.util.Vector;
/**
 * A parser that extracts INCLUDE statements from a Reader.
 * 
 * @author Curt Arnold
 */
public final class FortranParser extends AbstractParser implements Parser {
    private final Vector includes = new Vector();
    private AbstractParserState newLineState;
    /**
     * 
     *  
     */
    public FortranParser() {
        AbstractParserState filename = new FilenameState(this, new char[]{'\'',
                '/'});
        AbstractParserState apos = new WhitespaceOrLetterState(this, '\'',
                filename);
        AbstractParserState blank = new LetterState(this, ' ', apos, null);
        AbstractParserState e = new LetterState(this, 'E', blank, null);
        AbstractParserState d = new LetterState(this, 'D', e, null);
        AbstractParserState u = new LetterState(this, 'U', d, null);
        AbstractParserState l = new LetterState(this, 'L', u, null);
        AbstractParserState c = new LetterState(this, 'C', l, null);
        AbstractParserState n = new LetterState(this, 'N', c, null);
        newLineState = new WhitespaceOrLetterState(this, 'I', n);
    }
    public void addFilename(String include) {
        includes.addElement(include);
    }
    public String[] getIncludes() {
        String[] retval = new String[includes.size()];
        includes.copyInto(retval);
        return retval;
    }
    public AbstractParserState getNewLineState() {
        return newLineState;
    }
    public void parse(Reader reader) throws IOException {
        includes.setSize(0);
        super.parse(reader);
    }
}
